@@ -1181,6 +1181,7 @@ bool BufferParams::writeLaTeX(odocstream & os, LaTeXFeatures & features,
 			// default papersize ie PAPER_DEFAULT
 			switch (lyxrc.default_papersize) {
 			case PAPER_DEFAULT: // keep compiler happy
+				break;
 			case PAPER_USLETTER:
 				ods << ",letterpaper";
 				break;
@@ -1344,6 +1345,10 @@ bool BufferParams::writeLaTeX(odocstream & os, LaTeXFeatures & features,
 		texrow.newlines(lines);
 		// set back for the rest
 		lyxpreamble.clear();
+		// correctly break URLs with hyperref and dvi output
+		if (features.runparams().flavor == OutputParams::LATEX
+		    && features.isAvailable("breakurl"))
+			lyxpreamble += "\\usepackage{breakurl}\n";
 	}
 
 	// Will be surrounded by \makeatletter and \makeatother when not empty
