@@ -941,6 +941,7 @@ FuncStatus BufferView::getStatus(FuncRequest const & cmd)
 		flag.setEnabled(true);
 		break;
 
+	case LFUN_INSET_COPY_AS:
 	case LFUN_GRAPHICS_RELOAD:
 	case LFUN_COPY_LABEL_AS_REF: {
 		// if there is an inset at cursor, see whether it
@@ -1037,6 +1038,7 @@ FuncStatus BufferView::getStatus(FuncRequest const & cmd)
 			case BRANCH_CODE:
 			case BOX_CODE:
 			case LISTINGS_CODE:
+			case INFO_CODE:
 				enable = (cmd.argument().empty() ||
 					  cmd.getArg(0) == insetName(next_code));
 				break;
@@ -1401,6 +1403,7 @@ bool BufferView::dispatch(FuncRequest const & cmd)
 		buffer_.params().compressed = !buffer_.params().compressed;
 		break;
 
+	case LFUN_INSET_COPY_AS:
 	case LFUN_GRAPHICS_RELOAD: {
 		Inset * inset = cur.nextInset();
 		if (inset) {
@@ -2532,6 +2535,12 @@ DocIterator const & BufferView::inlineCompletionPos() const
 }
 
 
+bool BufferView::fixInlineCompletionPos()
+{
+	return d->inlineCompletionPos_.fixIfBroken();
+}
+
+
 bool samePar(DocIterator const & a, DocIterator const & b)
 {
 	if (a.empty() && b.empty())
