@@ -478,6 +478,8 @@ void copySelectionHelper(Buffer const & buf, ParagraphList const & pars,
 	// unless the whole selection was deleted
 	if (!isFullyDeleted(copy_pars))
 		acceptChanges(copy_pars, buf.params());
+	else
+		rejectChanges(copy_pars, buf.params());
 
 	DocumentClass * d = const_cast<DocumentClass *>(dc);
 	cutstack.push(make_pair(copy_pars, d));
@@ -958,7 +960,7 @@ void pasteClipboardGraphics(Cursor & cur, ErrorList & /* errorList */,
 	// create inset for graphic
 	InsetGraphics * inset = new InsetGraphics(cur.buffer());
 	InsetGraphicsParams params;
-	params.filename = support::DocFileName(filename.absFilename());
+	params.filename = support::DocFileName(filename.absFilename(), false);
 	inset->setParams(params);
 	cur.recordUndo();
 	cur.insert(inset);
