@@ -621,6 +621,10 @@ int LaTeX::scanLogFile(TeXErrors & terr)
 				   && contains(token, "undefined")) {
 				retval |= ERROR_RERUN;
 				LYXERR(Debug::LATEX, "Force rerun.");
+			// package etaremune
+			} else if (contains(token, "Etaremune labels have changed")) {
+				retval |= ERROR_RERUN;
+				LYXERR(Debug::LATEX, "Force rerun.");
 			} else if (contains(token, "Citation")
 				   && contains(token, "on page")
 				   && contains(token, "undefined")) {
@@ -639,6 +643,7 @@ int LaTeX::scanLogFile(TeXErrors & terr)
 			} else if (contains(token, "run BibTeX")) {
 				retval |= UNDEF_CIT;
 			} else if (contains(token, "Rerun LaTeX") ||
+				   contains(token, "Please rerun LaTeX") ||
 				   contains(token, "Rerun to get")) {
 				// at least longtable.sty and bibtopic.sty
 				// might use this.
