@@ -85,6 +85,15 @@ namespace os = support::os;
 
 bool use_gui = true;
 
+
+// Tell what files can be silently overwritten during batch export.
+// Possible values are: NO_FILES, MAIN_FILE, ALL_FILES, UNSPECIFIED.
+// Unless specified on command line (through the -f switch) or through the
+// environment variable LYX_FORCE_OVERWRITE, the default will be MAIN_FILE.
+
+OverwriteFiles force_overwrite = UNSPECIFIED;
+
+
 namespace {
 
 // Filled with the command line arguments "foo" of "-sysdir foo" or
@@ -427,7 +436,7 @@ int LyX::init(int & argc, char * argv[])
 		return EXIT_FAILURE;
 
 	// Remaining arguments are assumed to be files to load.
-	for (int argi = argc - 1; argi >= 1; --argi)
+	for (int argi = 1; argi < argc; ++argi)
 		pimpl_->files_to_load_.push_back(os::utf8_argv(argi));
 
 	if (first_start) {
@@ -694,9 +703,20 @@ bool LyX::init()
 	if (queryUserLyXDir(package().explicit_user_support()))
 		reconfigureUserLyXDir();
 
-	// no need for a splash when there is no GUI
 	if (!use_gui) {
+		// No need for a splash when there is no GUI
 		first_start = false;
+		// Default is to overwrite the main file during export, unless
+		// the -f switch was specified or LYX_FORCE_OVERWRITE was set
+		if (force_overwrite == UNSPECIFIED) {
+			string const what = getEnv("LYX_FORCE_OVERWRITE");
+			if (what == "all")
+				force_overwrite = ALL_FILES;
+			else if (what == "none")
+				force_overwrite = NO_FILES;
+			else
+				force_overwrite = MAIN_FILE;
+		}
 	}
 
 	// This one is generated in user_support directory by lib/configure.py.
@@ -971,6 +991,11 @@ int parse_help(string const &, string const &, string &)
 		  "\t-i [--import] fmt file.xxx\n"
 		  "                  where fmt is the import format of choice\n"
 		  "                  and file.xxx is the file to be imported.\n"
+		  "\t-f [--force-overwrite] what\n"
+		  "                  where what is either `all', `main' or `none',\n"
+		  "                  specifying whether all files, main file only, or no files,\n"
+		  "                  respectively, are to be overwritten during a batch export.\n"
+		  "                  Anything else is equivalent to `all', but is not consumed.\n"
 		  "\t-version        summarize version and build info\n"
 			       "Check the LyX man page for more details.")) << endl;
 	exit(0);
@@ -1065,6 +1090,23 @@ int parse_geometry(string const & arg1, string const &, string &)
 }
 
 
+int parse_force(string const & arg, string const &, string &) 
+{
+	if (arg == "all") {
+		force_overwrite = ALL_FILES;
+		return 1;
+	} else if (arg == "main") {
+		force_overwrite = MAIN_FILE;
+		return 1;
+	} else if (arg == "none") {
+		force_overwrite = NO_FILES;
+		return 1;
+	}
+	force_overwrite = ALL_FILES;
+	return 0;
+}
+
+
 } // namespace anon
 
 
@@ -1086,6 +1128,8 @@ void LyX::easyParse(int & argc, char * argv[])
 	cmdmap["-i"] = parse_import;
 	cmdmap["--import"] = parse_import;
 	cmdmap["-geometry"] = parse_geometry;
+	cmdmap["-f"] = parse_force;
+	cmdmap["--force-overwrite"] = parse_force;
 
 	for (int i = 1; i < argc; ++i) {
 		map<string, cmd_helper>::const_iterator it
