@@ -1253,7 +1253,6 @@ void LyXFunc::dispatch(FuncRequest const & cmd)
 			switch (code) {
 			case BIBITEM_CODE:
 			case BIBTEX_CODE:
-			case INDEX_CODE:
 			case LABEL_CODE:
 			case NOMENCL_CODE:
 			case REF_CODE:
@@ -1782,8 +1781,10 @@ void LyXFunc::dispatch(FuncRequest const & cmd)
 			if (view()->cursor() != old) {
 				old.fixIfBroken();
 				bool badcursor = notifyCursorLeaves(old, view()->cursor());
-				if (badcursor)
+				if (badcursor) {
 					view()->cursor().fixIfBroken();
+					view()->fixInlineCompletionPos();
+				}
 			}
 
 			if (theBufferList().isLoaded(buffer))
