@@ -368,6 +368,18 @@ void GuiView::saveLayout() const
 }
 
 
+void GuiView::saveUISettings() const
+{
+	ToolbarMap::iterator end = d.toolbars_.end();
+	for (ToolbarMap::iterator it = d.toolbars_.begin(); it != end; ++it)
+		it->second->saveSession();
+	// Now take care of all other dialogs:
+	map<string, DialogPtr>::const_iterator it = d.dialogs_.begin();
+	for (; it!= d.dialogs_.end(); ++it)
+		it->second->saveSession();
+}
+
+
 bool GuiView::restoreLayout()
 {
 	QSettings settings;
@@ -554,16 +566,8 @@ void GuiView::closeEvent(QCloseEvent * close_event)
 	// Saving fullscreen requires additional tweaks in the toolbar code.
 	// It wouldn't also work under linux natively.
 	if (lyxrc.allow_geometry_session) {
-		// Save this window geometry and layout.
 		saveLayout();
-		// Then the toolbar private states.
-		ToolbarMap::iterator end = d.toolbars_.end();
-		for (ToolbarMap::iterator it = d.toolbars_.begin(); it != end; ++it)
-			it->second->saveSession();
-		// Now take care of all other dialogs:
-		map<string, DialogPtr>::const_iterator it = d.dialogs_.begin();
-		for (; it!= d.dialogs_.end(); ++it)
-			it->second->saveSession();
+		saveUISettings();
 	}
 
 	close_event->accept();
@@ -1391,7 +1395,13 @@ Buffer * GuiView::loadDocument(FileName const & filename, bool tolastfiles)
 {
 	setBusy(true);
 
-	Buffer * newBuffer = checkAndLoadLyXFile(filename);
+	Buffer * newBuffer = 0;
+	try {
+		newBuffer = checkAndLoadLyXFile(filename);
+	} catch (ExceptionMessage const & e) {
+		setBusy(false);
+		throw(e);
+	}
 
 	if (!newBuffer) {
 		message(_("Document not loaded."));
@@ -2426,7 +2436,7 @@ namespace {
 char const * const dialognames[] = {
 "aboutlyx", "bibitem", "bibtex", "box", "branch", "changes", "character",
 "citation", "document", "errorlist", "ert", "external", "file",
-"findreplace", "float", "graphics", "include", "index", "info", "nomenclature", "label", "log",
+"findreplace", "float", "graphics", "include", "info", "nomenclature", "label", "log",
 "mathdelimiter", "mathmatrix", "mathspace", "note", "paragraph", "prefs", "print", 
 "ref", "sendto", "space", "spellchecker", "symbols", "tabular", "tabularcreate",
 
@@ -2464,6 +2474,7 @@ void GuiView::resetDialogs()
 	// Make sure that no LFUN uses any LyXView.
 	theLyXFunc().setLyXView(0);
 	saveLayout();
+	saveUISettings();
 	menuBar()->clear();
 	constructToolbars();
 	guiApp->menus().fillMenuBar(menuBar(), this, false);
