@@ -121,6 +121,8 @@ public:
 
 	/// identification as math inset
 	virtual InsetMath * asInsetMath() { return 0; }
+	/// identification as math inset
+	virtual InsetMath const * asInsetMath() const { return 0; }
 	/// true for 'math' math inset, but not for e.g. mbox
 	virtual bool inMathed() const { return false; }
 	/// is this inset based on the InsetText class?
@@ -440,7 +442,8 @@ public:
 	 *  Most insets have no interest in this capability, so the method
 	 *  defaults to empty.
 	 */
-	virtual void addPreview(graphics::PreviewLoader &) const {}
+	virtual void addPreview(DocIterator const &,
+		graphics::PreviewLoader &) const {}
 
 	/** Classifies the unicode characters appearing in a math inset
 	 *  depending on whether they are to be translated as latex
@@ -472,6 +475,8 @@ public:
 	virtual mode_type currentMode() const { return UNDECIDED_MODE; }
 	/// returns whether changing mode during latex export is forbidden
 	virtual bool lockedMode() const { return false; }
+	/// returns whether only ascii chars are allowed during latex export
+	virtual bool asciiOnly() const { return false; }
 	/// returns whether this inset is allowed in other insets of given mode
 	virtual bool allowedIn(mode_type) const { return true; }
 	/**
@@ -496,7 +501,7 @@ public:
 	///
 	int scroll() const { return 0; }
 	///
-	virtual ColorCode backgroundColor() const;
+	virtual ColorCode backgroundColor(PainterInfo const &) const;
 	///
 	enum CollapseStatus {
 		Collapsed,
