@@ -65,9 +65,9 @@ static int extractInt(istream & is)
 static void resetGrid(InsetMathGrid & grid)
 {
 	while (grid.ncols() > 1)
-		grid.delCol(grid.ncols());
+		grid.delCol(grid.ncols() - 1);
 	while (grid.nrows() > 1)
-		grid.delRow(grid.nrows());
+		grid.delRow(grid.nrows() - 1);
 	grid.cell(0).erase(0, grid.cell(0).size());
 	grid.setDefaults();
 }
@@ -1455,7 +1455,7 @@ bool InsetMathGrid::getStatus(Cursor & cur, FuncRequest const & cmd,
 	}
 
 	case LFUN_CELL_SPLIT:
-		status.setEnabled(true);
+		status.setEnabled(cur.idx() != cur.lastidx());
 		return true;
 
 	case LFUN_CELL_BACKWARD:
