@@ -213,7 +213,7 @@ bool addCol(InsetMathGrid & grid, InsetMathGrid::col_type & cellcol)
 
 
 /*!
- * Check wether the last row is empty and remove it if yes.
+ * Check whether the last row is empty and remove it if yes.
  * Otherwise the following code
  * \verbatim
 \begin{array}{|c|c|}
@@ -224,6 +224,8 @@ bool addCol(InsetMathGrid & grid, InsetMathGrid::col_type & cellcol)
  * \endverbatim
  * will result in a grid with 3 rows (+ the dummy row that is always present),
  * because the last '\\' opens a new row.
+ * Note that this is only needed for inner-hull grid types, such as array
+ * or aligned, but not for outer-hull grid types, such as eqnarray or align.
  */
 void delEmptyLastRow(InsetMathGrid & grid)
 {
@@ -240,6 +242,19 @@ void delEmptyLastRow(InsetMathGrid & grid)
 }
 
 
+/*!
+ * Tell whether the environment name corresponds to an inner-hull grid type.
+ */
+bool innerHull(docstring const & name)
+{
+	// For [bB]matrix, [vV]matrix, and pmatrix we can check the suffix only
+	return name == "array" || name == "cases" || name == "aligned"
+		|| name == "alignedat" || name == "gathered" || name == "split"
+		|| name == "subarray" || name == "tabular" || name == "matrix"
+		|| name.substr(1) == "matrix";
+}
+
+
 // These are TeX's catcodes
 enum CatCode {
 	catEscape,     // 0    backslash
@@ -613,6 +628,8 @@ void Parser::tokenize(docstring const & buffer)
 				if (!is) {
 					error("unexpected end of input");
 				} else {
+					if (c == '\n')
+						c = ' ';
 					docstring s(1, c);
 					if (catcode(c) == catLetter) {
 						// collect letters
@@ -831,9 +848,16 @@ bool Parser::parse1(InsetMathGrid & grid, unsigned flags,
 				Token const & n = getToken();
 				if (n.cat() == catMath) {
 					// TeX's $$...$$ syntax for displayed math
-					cell->push_back(MathAtom(new InsetMathHull(buf, hullEquation)));
-					parse2(cell->back(), FLAG_SIMPLE, InsetMath::MATH_MODE, false);
-					getToken(); // skip the second '$' token
+					if (mode == InsetMath::UNDECIDED_MODE) {
+						cell->push_back(MathAtom(new InsetMathHull(buf, hullEquation)));
+						parse2(cell->back(), FLAG_SIMPLE, InsetMath::MATH_MODE, false);
+						getToken(); // skip the second '$' token
+					} else {
+						// This is not an outer hull and display math is
+						// not allowed inside text mode environments.
+						error("bad math environment");
+						break;
+					}
 				} else {
 					// simple $...$  stuff
 					putback();
@@ -854,8 +878,19 @@ bool Parser::parse1(InsetMathGrid & grid, unsigned flags,
 			}
 
 			else {
-				error("something strange in the parser");
-				break;
+				Token const & n = getToken();
+				if (n.cat() == catMath) {
+					error("something strange in the parser");
+					break;
+				} else {
+					// This is inline math ($...$), but the parser thinks we are
+					// already in math mode and latex would issue an error, unless we
+					// are inside a text mode user macro. We have no way to tell, so
+					// let's play safe by using \ensuremath, as it will work in any case.
+					putback();
+					cell->push_back(MathAtom(new InsetMathEnsureMath(buf)));
+					parse(cell->back().nucleus()->cell(0), FLAG_SIMPLE, InsetMath::MATH_MODE);
+				}
 			}
 		}
 
@@ -1199,12 +1234,8 @@ bool Parser::parse1(InsetMathGrid & grid, unsigned flags,
 		}
 
 		else if (t.cs() == "(") {
-			if (mode == InsetMath::MATH_MODE) {
-				error("bad math environment");
-				break;
-			}
-			cell->push_back(MathAtom(new InsetMathHull(buf, hullSimple)));
-			parse2(cell->back(), FLAG_SIMPLE2, InsetMath::MATH_MODE, false);
+			cell->push_back(MathAtom(new InsetMathEnsureMath(buf)));
+			parse(cell->back().nucleus()->cell(0), FLAG_SIMPLE2, InsetMath::MATH_MODE);
 		}
 
 		else if (t.cs() == "[") {
@@ -1241,7 +1272,7 @@ bool Parser::parse1(InsetMathGrid & grid, unsigned flags,
 					// probably need to refine this test.
 					// Right now we only have to test for
 					// single line hull insets.
-					if (grid.nrows() > 1)
+					if (grid.nrows() > 1 && innerHull(name))
 						delEmptyLastRow(grid);
 					return success_;
 				}
@@ -1476,12 +1507,8 @@ bool Parser::parse1(InsetMathGrid & grid, unsigned flags,
 			}
 
 			else if (name == "math") {
-				if (mode == InsetMath::MATH_MODE) {
-					error("bad math environment");
-					break;
-				}
-				cell->push_back(MathAtom(new InsetMathHull(buf, hullSimple)));
-				parse2(cell->back(), FLAG_END, InsetMath::MATH_MODE, true);
+				cell->push_back(MathAtom(new InsetMathEnsureMath(buf)));
+				parse(cell->back().nucleus()->cell(0), FLAG_END, InsetMath::MATH_MODE);
 			}
 
 			else if (name == "equation" || name == "equation*"
@@ -1679,6 +1706,11 @@ bool Parser::parse1(InsetMathGrid & grid, unsigned flags,
 		else if (t.cs() == "substack") {
 			cell->push_back(createInsetMath(t.cs(), buf));
 			parse2(cell->back(), FLAG_ITEM, mode, false);
+			// Delete empty last row if present
+			InsetMathGrid & subgrid =
+				*(cell->back().nucleus()->asGridInset());
+			if (subgrid.nrows() > 1)
+				delEmptyLastRow(subgrid);
 		}
 
 		else if (t.cs() == "xymatrix") {
@@ -1687,6 +1719,11 @@ bool Parser::parse1(InsetMathGrid & grid, unsigned flags,
 				os << getToken().asInput();
 			cell->push_back(createInsetMath(t.cs() + os.str(), buf));
 			parse2(cell->back(), FLAG_ITEM, mode, false);
+			// Delete empty last row if present
+			InsetMathGrid & subgrid =
+				*(cell->back().nucleus()->asGridInset());
+			if (subgrid.nrows() > 1)
+				delEmptyLastRow(subgrid);
 		}
 
 		else if (t.cs() == "framebox" || t.cs() == "makebox") {
