@@ -80,6 +80,7 @@ extern "C" int mkstemp(char *);
 #endif // SUM_WITH_MMAP
 
 using namespace std;
+using namespace lyx::support;
 
 // OK, this is ugly, but it is the only workaround I found to compile
 // with gcc (any version) on a system which uses a non-GNU toolchain.
@@ -204,7 +205,7 @@ string FileName::absFilename() const
 
 string FileName::realPath() const
 {
-	return os::real_path(toFilesystemEncoding());
+	return os::real_path(absFilename());
 }
 
 
@@ -284,13 +285,22 @@ bool FileName::changePermission(unsigned long int mode) const
 
 string FileName::toFilesystemEncoding() const
 {
-	// FIXME: This doesn't work on Windows for non ascii file names with Qt < 4.4.
-	// Provided that Windows package uses Qt4.4, this isn't a problem.
+	// This doesn't work on Windows for non ascii file names.
 	QByteArray const encoded = QFile::encodeName(d->fi.absoluteFilePath());
 	return string(encoded.begin(), encoded.end());
 }
 
 
+string FileName::toSafeFilesystemEncoding(os::file_access how) const
+{
+	// This will work on Windows for non ascii file names.
+	QString const safe_path =
+		toqstr(os::safe_internal_path(absFilename(), how));
+	QByteArray const encoded = QFile::encodeName(safe_path);
+	return string(encoded.begin(), encoded.end());
+}
+
+
 FileName FileName::fromFilesystemEncoding(string const & name)
 {
 	QByteArray const encoded(name.c_str(), name.length());
@@ -474,6 +484,12 @@ FileName FileName::tempPath()
 }
 
 
+void FileName::refresh() const
+{
+	d->refresh();
+}
+
+
 time_t FileName::lastModified() const
 {
 	// QFileInfo caches information about the file. So, in case this file has
@@ -530,7 +546,7 @@ unsigned long FileName::checksum() const
 
 #else // QT_VERSION
 
-	string const encoded = toFilesystemEncoding();
+	string const encoded = toSafeFilesystemEncoding();
 	char const * file = encoded.c_str();
 
  #ifdef SUM_WITH_MMAP
@@ -1109,7 +1125,7 @@ string DocFileName::mangledFilename(string const & dir) const
 	// in the name.
 	static string const keep = "abcdefghijklmnopqrstuvwxyz"
 				   "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
-				   "+,-0123456789;=";
+				   "+-0123456789;=";
 	string::size_type pos = 0;
 	while ((pos = mname.find_first_not_of(keep, pos)) != string::npos)
 		mname[pos++] = '_';
